@@ -13,12 +13,17 @@ how the entire pipeline can be run on tiles or images, respectively.
 
     # Get image filepath
     filepath = '/path/to/image.ext'
+    config = 'mvp'
 
     # Run tiling
     img_shape, tile_grids, tile_filepaths = tile.compute(filepath)
 
     # Run WIC
-    wic_outputs = wic.post(wic.predict(wic.pre(tile_filepaths)))
+    wic_outputs = wic.post(wic.predict(wic.pre(
+        tile_filepaths,
+        config=config,
+        # batch_size=wic_batch_size,  # Optional override of config
+    )))
 
     # Threshold for WIC
     flags = [wic_output.get('positive') >= wic_thresh for wic_output in wic_outputs]
@@ -28,10 +33,10 @@ how the entire pipeline can be run on tiles or images, respectively.
     # Run localizer
     loc_outputs = loc.post(
         loc.predict(
-            loc.pre(loc_tile_filepaths)
+            loc.pre(loc_tile_filepaths, config=config)
         ),
-        loc_thresh=loc_thresh,
-        nms_thresh=loc_nms_thresh
+        # loc_thresh=loc_thresh,  # Optional override of config
+        # nms_thresh=loc_nms_thresh,  # Optional override of config
     )
 
     # Run Aggregation and get final detections
@@ -39,8 +44,9 @@ how the entire pipeline can be run on tiles or images, respectively.
         img_shape,
         loc_tile_grids,
         loc_outputs,
-        agg_thresh=agg_thresh,
-        nms_thresh=agg_nms_thresh,
+        config=config,
+        # agg_thresh=agg_thresh,  # Optional override of config
+        # nms_thresh=agg_nms_thresh,  # Optional override of config
     )
 '''
 from os.path import exists
@@ -51,16 +57,17 @@ import utool as ut
 from scoutbot import utils
 
 log = utils.init_logging()
+QUIET = not utils.VERBOSE
 
 
 from scoutbot import agg, loc, tile, wic  # NOQA
 
-VERSION = '0.1.13'
+VERSION = '0.1.16'
 version = VERSION
 __version__ = VERSION
 
 
-def fetch(pull=False):
+def fetch(pull=False, config=None):
     """
     Fetch the WIC and Localizer ONNX model files from a CDN if they do not exist locally.
 
@@ -68,8 +75,10 @@ def fetch(pull=False):
     files otherwise do not exist locally on disk.
 
     Args:
-        pull (bool, optional): If :obj:`True`, use the downloaded versions stored in
-            the local system's cache.  Defaults to :obj:`False`.
+        pull (bool, optional): If :obj:`True`, force using the downloaded versions
+            stored in the local system's cache.  Defaults to :obj:`False`.
+        config (str or None, optional): the configuration to use, one of ``phase1``
+            or ``mvp``.  Defaults to :obj:`None`.
 
     Returns:
         None
@@ -77,17 +86,18 @@ def fetch(pull=False):
     Raises:
         AssertionError: If any model cannot be fetched.
     """
-    wic.fetch(pull=pull)
-    loc.fetch(pull=pull)
+    wic.fetch(pull=pull, config=None)
+    loc.fetch(pull=pull, config=None)
 
 
 def pipeline(
     filepath,
-    wic_thresh=wic.WIC_THRESH,
-    loc_thresh=loc.LOC_THRESH,
-    loc_nms_thresh=loc.NMS_THRESH,
-    agg_thresh=agg.AGG_THRESH,
-    agg_nms_thresh=agg.NMS_THRESH,
+    config=None,
+    wic_thresh=wic.CONFIGS[None]['thresh'],
+    loc_thresh=loc.CONFIGS[None]['thresh'],
+    loc_nms_thresh=loc.CONFIGS[None]['nms'],
+    agg_thresh=agg.CONFIGS[None]['thresh'],
+    agg_nms_thresh=agg.CONFIGS[None]['nms'],
     clean=True,
 ):
     """
@@ -109,9 +119,24 @@ def pipeline(
 
     Args:
         filepath (str): image filepath (relative or absolute)
+        config (str or None, optional): the configuration to use, one of ``phase1``
+            or ``mvp``.  Defaults to :obj:`None`.
+        wic_thresh (float or None, optional): the confidence threshold for the WIC's
+            predictions.  Defaults to the default configuration setting.
+        loc_thresh (float or None, optional): the confidence threshold for the localizer's
+            predictions.  Defaults to the default configuration setting.
+        nms_thresh (float or None, optional): the non-maximum suppression (NMS) threshold
+            for the localizer's predictions.  Defaults to the default configuration setting.
+        agg_thresh (float or None, optional): the confidence threshold for the aggregated
+            localizer predictions. Defaults to the default configuration setting.
+        agg_nms_thresh (float or None, optional): the non-maximum suppression (NMS) threshold
+            for the aggregated localizer's predictions.  Defaults to the default
+            configuration setting.
+        clean (bool, optional): a flag to clean up any on-disk tiles that were generated.
+            Defaults to :obj:`True`.
 
     Returns:
-        list ( dict ): list of predictions
+        tuple ( float, list ( dict ) ): wic score, list of predictions
     """
     import utool as ut
 
@@ -119,18 +144,19 @@ def pipeline(
     img_shape, tile_grids, tile_filepaths = tile.compute(filepath)
 
     # Run WIC
-    wic_outputs = wic.post(wic.predict(wic.pre(tile_filepaths)))
+    wic_outputs = wic.post(wic.predict(wic.pre(tile_filepaths, config=config)))
 
     # Threshold for WIC
+    wic_ = max(wic_output.get('positive') for wic_output in wic_outputs)
     flags = [wic_output.get('positive') >= wic_thresh for wic_output in wic_outputs]
     loc_tile_grids = ut.compress(tile_grids, flags)
     loc_tile_filepaths = ut.compress(tile_filepaths, flags)
 
-    log.info(f'Filtered to {len(loc_tile_filepaths)} tiles')
+    log.debug(f'Filtered to {len(loc_tile_filepaths)} tiles')
 
     # Run localizer
     loc_outputs = loc.post(
-        loc.predict(loc.pre(loc_tile_filepaths)),
+        loc.predict(loc.pre(loc_tile_filepaths, config=config)),
         loc_thresh=loc_thresh,
         nms_thresh=loc_nms_thresh,
     )
@@ -141,6 +167,7 @@ def pipeline(
         img_shape,
         loc_tile_grids,
         loc_outputs,
+        config=config,
         agg_thresh=agg_thresh,
         nms_thresh=agg_nms_thresh,
     )
@@ -150,16 +177,17 @@ def pipeline(
             if exists(tile_filepath):
                 ut.delete(tile_filepath, verbose=False)
 
-    return detects
+    return wic_, detects
 
 
 def batch(
     filepaths,
-    wic_thresh=wic.WIC_THRESH,
-    loc_thresh=loc.LOC_THRESH,
-    loc_nms_thresh=loc.NMS_THRESH,
-    agg_thresh=agg.AGG_THRESH,
-    agg_nms_thresh=agg.NMS_THRESH,
+    config=None,
+    wic_thresh=wic.CONFIGS[None]['thresh'],
+    loc_thresh=loc.CONFIGS[None]['thresh'],
+    loc_nms_thresh=loc.CONFIGS[None]['nms'],
+    agg_thresh=agg.CONFIGS[None]['thresh'],
+    agg_nms_thresh=agg.CONFIGS[None]['nms'],
     clean=True,
 ):
     """
@@ -183,9 +211,24 @@ def batch(
 
     Args:
         filepaths (list): list of str image filepath (relative or absolute)
+        config (str or None, optional): the configuration to use, one of ``phase1``
+            or ``mvp``.  Defaults to :obj:`None`.
+        wic_thresh (float or None, optional): the confidence threshold for the WIC's
+            predictions.  Defaults to the default configuration setting.
+        loc_thresh (float or None, optional): the confidence threshold for the localizer's
+            predictions.  Defaults to the default configuration setting.
+        nms_thresh (float or None, optional): the non-maximum suppression (NMS) threshold
+            for the localizer's predictions.  Defaults to the default configuration setting.
+        agg_thresh (float or None, optional): the confidence threshold for the aggregated
+            localizer predictions.  Defaults to the default configuration setting.
+        agg_nms_thresh (float or None, optional): the non-maximum suppression (NMS) threshold
+            for the aggregated localizer's predictions.  Defaults to the default
+            configuration setting.
+        clean (bool, optional): a flag to clean up any on-disk tiles that were generated.
+            Defaults to :obj:`True`.
 
     Returns:
-        list ( list ( dict ) ) : corresponding list of lists of predictions
+        tuple ( list ( float ), list ( list ( dict ) ) : corresponding list of wic scores, corresponding list of lists of predictions
     """
     import utool as ut
 
@@ -217,7 +260,15 @@ def batch(
         tile_grids += batch_grids
         tile_filepaths += batch_filepaths
 
-    wic_outputs = wic.post(wic.predict(wic.pre(tile_filepaths)))
+    wic_outputs = wic.post(wic.predict(wic.pre(tile_filepaths, config=config)))
+
+    wic_dict = {}
+    for tile_img_filepath, wic_output in zip(tile_img_filepaths, wic_outputs):
+        wic_ = wic_output.get('positive')
+        existing_wic_ = wic_dict.get(tile_img_filepath, None)
+        if existing_wic_ is None:
+            existing_wic_ = wic_
+        wic_dict[tile_img_filepath] = max(existing_wic_, wic_)
 
     # Threshold for WIC
     flags = [wic_output.get('positive') >= wic_thresh for wic_output in wic_outputs]
@@ -225,11 +276,11 @@ def batch(
     loc_tile_grids = ut.compress(tile_grids, flags)
     loc_tile_filepaths = ut.compress(tile_filepaths, flags)
 
-    log.info(f'Filtered to {len(loc_tile_filepaths)} tiles')
+    log.debug(f'Filtered to {len(loc_tile_filepaths)} tiles')
 
     # Run localizer
     loc_outputs = loc.post(
-        loc.predict(loc.pre(loc_tile_filepaths)),
+        loc.predict(loc.pre(loc_tile_filepaths, config=config)),
         loc_thresh=loc_thresh,
         nms_thresh=loc_nms_thresh,
     )
@@ -242,9 +293,11 @@ def batch(
         batch[filepath]['loc']['outputs'].append(loc_output)
 
     # Run Aggregation
+    wic_list = []
     detects_list = []
     for filepath in filepaths:
         data = batch[filepath]
+        wic_ = wic_dict.get(filepath, None)
 
         img_shape = data['shape']
         loc_tile_grids = data['loc']['grids']
@@ -255,9 +308,12 @@ def batch(
             img_shape,
             loc_tile_grids,
             loc_outputs,
+            config=config,
             agg_thresh=agg_thresh,
             nms_thresh=agg_nms_thresh,
         )
+
+        wic_list.append(wic_)
         detects_list.append(detects)
 
     if clean:
@@ -265,12 +321,12 @@ def batch(
             if exists(tile_filepath):
                 ut.delete(tile_filepath, verbose=False)
 
-    return detects_list
+    return wic_list, detects_list
 
 
 def example():
     """
-    Run the pipeline on an example image
+    Run the pipeline on an example image with the Phase 1 models
     """
     TEST_IMAGE = 'scout.example.jpg'
     TEST_IMAGE_HASH = (
@@ -284,8 +340,8 @@ def example():
     )
     assert exists(img_filepath)
 
-    log.info(f'Running pipeline on image: {img_filepath}')
+    log.debug(f'Running pipeline on image: {img_filepath}')
 
-    detects = pipeline(img_filepath)
+    wic_, detects = pipeline(img_filepath)
 
-    log.info(ut.repr3(detects))
+    log.debug(ut.repr3(detects))
