@@ -21,11 +21,17 @@ def pipeline_filepath_validator(ctx, param, value):
 
 
 @click.command('fetch')
-def fetch():
+@click.option(
+    '--config',
+    help='Which ML models to use for inference',
+    default=None,
+    type=click.Choice(['phase1', 'mvp', 'old', 'new']),
+)
+def fetch(config):
     """
     Fetch the required machine learning ONNX models for the WIC and LOC
     """
-    scoutbot.fetch()
+    scoutbot.fetch(config=config)
 
 
 @click.command('pipeline')
@@ -35,6 +41,12 @@ def fetch():
     type=str,
     callback=pipeline_filepath_validator,
 )
+@click.option(
+    '--config',
+    help='Which ML models to use for inference',
+    default=None,
+    type=click.Choice(['phase1', 'mvp', 'old', 'new']),
+)
 @click.option(
     '--output',
     help='Path to output JSON (if unspecified, results are printed to screen)',
@@ -44,47 +56,77 @@ def fetch():
 @click.option(
     '--wic_thresh',
     help='Whole Image Classifier (WIC) confidence threshold',
-    default=int(wic.WIC_THRESH * 100),
+    default=int(wic.CONFIGS[None]['thresh'] * 100),
     type=click.IntRange(0, 100, clamp=True),
 )
 @click.option(
     '--loc_thresh',
     help='Localizer (LOC) confidence threshold',
-    default=int(loc.LOC_THRESH * 100),
+    default=int(loc.CONFIGS[None]['thresh'] * 100),
     type=click.IntRange(0, 100, clamp=True),
 )
 @click.option(
     '--loc_nms_thresh',
     help='Localizer (LOC) non-maximum suppression (NMS) threshold',
-    default=int(loc.NMS_THRESH * 100),
+    default=int(loc.CONFIGS[None]['nms'] * 100),
     type=click.IntRange(0, 100, clamp=True),
 )
 @click.option(
     '--agg_thresh',
     help='Aggregation (AGG) confidence threshold',
-    default=int(agg.AGG_THRESH * 100),
+    default=int(agg.CONFIGS[None]['thresh'] * 100),
     type=click.IntRange(0, 100, clamp=True),
 )
 @click.option(
     '--agg_nms_thresh',
     help='Aggregation (AGG) non-maximum suppression (NMS) threshold',
-    default=int(agg.NMS_THRESH * 100),
+    default=int(agg.CONFIGS[None]['nms'] * 100),
     type=click.IntRange(0, 100, clamp=True),
 )
 def pipeline(
-    filepath, output, wic_thresh, loc_thresh, loc_nms_thresh, agg_thresh, agg_nms_thresh
+    filepath,
+    config,
+    output,
+    wic_thresh,
+    loc_thresh,
+    loc_nms_thresh,
+    agg_thresh,
+    agg_nms_thresh,
 ):
     """
-    Run the ScoutBot pipeline on an input image filepath
+    Run the ScoutBot pipeline on an input image filepath.  An example output of the JSON
+    can be seen below.
+
+    .. code-block:: javascript
+
+            {
+                '/path/to/image.ext': {
+                    'wic': 0.5,
+                    'loc': [
+                        {
+                            'l': 'elephant',
+                            'c': 0.9,
+                            'x': 100,
+                            'y': 100,
+                            'w': 50,
+                            'h': 10
+                        },
+                        ...
+                    ],
+                }
+            }
     """
+    if config is not None:
+        config = config.strip().lower()
     wic_thresh /= 100.0
     loc_thresh /= 100.0
     loc_nms_thresh /= 100.0
     agg_thresh /= 100.0
     agg_nms_thresh /= 100.0
 
-    detects = scoutbot.pipeline(
+    wic_, detects = scoutbot.pipeline(
         filepath,
+        config=config,
         wic_thresh=wic_thresh,
         loc_thresh=loc_thresh,
         loc_nms_thresh=loc_nms_thresh,
@@ -92,11 +134,18 @@ def pipeline(
         agg_nms_thresh=agg_nms_thresh,
     )
 
+    data = {
+        filepath: {
+            'wic': wic_,
+            'loc': detects,
+        }
+    }
+
     if output:
         with open(output, 'w') as outfile:
-            json.dump(detects, outfile)
+            json.dump(data, outfile)
     else:
-        log.info(ut.repr3(detects))
+        print(ut.repr3(data))
 
 
 @click.command('batch')
@@ -105,6 +154,12 @@ def pipeline(
     nargs=-1,
     type=str,
 )
+@click.option(
+    '--config',
+    help='Which ML models to use for inference',
+    default=None,
+    type=click.Choice(['phase1', 'mvp', 'old', 'new']),
+)
 @click.option(
     '--output',
     help='Path to output JSON (if unspecified, results are printed to screen)',
@@ -114,71 +169,120 @@ def pipeline(
 @click.option(
     '--wic_thresh',
     help='Whole Image Classifier (WIC) confidence threshold',
-    default=int(wic.WIC_THRESH * 100),
+    default=int(wic.CONFIGS[None]['thresh'] * 100),
     type=click.IntRange(0, 100, clamp=True),
 )
 @click.option(
     '--loc_thresh',
     help='Localizer (LOC) confidence threshold',
-    default=int(loc.LOC_THRESH * 100),
+    default=int(loc.CONFIGS[None]['thresh'] * 100),
     type=click.IntRange(0, 100, clamp=True),
 )
 @click.option(
     '--loc_nms_thresh',
     help='Localizer (LOC) non-maximum suppression (NMS) threshold',
-    default=int(loc.NMS_THRESH * 100),
+    default=int(loc.CONFIGS[None]['nms'] * 100),
     type=click.IntRange(0, 100, clamp=True),
 )
 @click.option(
     '--agg_thresh',
     help='Aggregation (AGG) confidence threshold',
-    default=int(agg.AGG_THRESH * 100),
+    default=int(agg.CONFIGS[None]['thresh'] * 100),
     type=click.IntRange(0, 100, clamp=True),
 )
 @click.option(
     '--agg_nms_thresh',
     help='Aggregation (AGG) non-maximum suppression (NMS) threshold',
-    default=int(agg.NMS_THRESH * 100),
+    default=int(agg.CONFIGS[None]['nms'] * 100),
     type=click.IntRange(0, 100, clamp=True),
 )
 def batch(
-    filepaths, output, wic_thresh, loc_thresh, loc_nms_thresh, agg_thresh, agg_nms_thresh
+    filepaths,
+    config,
+    output,
+    wic_thresh,
+    loc_thresh,
+    loc_nms_thresh,
+    agg_thresh,
+    agg_nms_thresh,
 ):
     """
-    Run the ScoutBot pipeline in batch on a list of input image filepaths
+    Run the ScoutBot pipeline in batch on a list of input image filepaths.
+    An example output of the JSON can be seen below.
+
+    .. code-block:: javascript
+
+            {
+                '/path/to/image1.ext': {
+                    'wic': 0.5,
+                    'loc': [
+                        {
+                            'l': 'elephant',
+                            'c': 0.9,
+                            'x': 100,
+                            'y': 100,
+                            'w': 50,
+                            'h': 10
+                        },
+                        ...
+                    ],
+                },
+                '/path/to/image2.ext': {
+                    'wic': 0.5,
+                    'loc': [
+                        {
+                            'l': 'elephant',
+                            'c': 0.9,
+                            'x': 100,
+                            'y': 100,
+                            'w': 50,
+                            'h': 10
+                        },
+                        ...
+                    ],
+                },
+                ...
+            }
     """
+    if config is not None:
+        config = config.strip().lower()
     wic_thresh /= 100.0
     loc_thresh /= 100.0
     loc_nms_thresh /= 100.0
     agg_thresh /= 100.0
     agg_nms_thresh /= 100.0
 
-    log.info(f'Running batch on {len(filepaths)} files...')
+    log.debug(f'Running batch on {len(filepaths)} files...')
 
-    detects_list = scoutbot.batch(
+    wic_list, detects_list = scoutbot.batch(
         filepaths,
+        config=config,
         wic_thresh=wic_thresh,
         loc_thresh=loc_thresh,
         loc_nms_thresh=loc_nms_thresh,
         agg_thresh=agg_thresh,
         agg_nms_thresh=agg_nms_thresh,
     )
-    results = zip(filepaths, detects_list)
+    results = zip(filepaths, wic_list, detects_list)
+
+    data = {}
+    for filepath, wic_, detects in results:
+        data[filepath] = {
+            'wic': wic,
+            'loc': detects,
+        }
 
     if output:
-        detects = dict(results)
         with open(output, 'w') as outfile:
-            json.dump(detects, outfile)
+            json.dump(data, outfile)
     else:
-        for filepath, detects in results:
-            log.info(filepath)
-            log.info(ut.repr3(detects))
+        print(ut.repr3(data))
 
 
 @click.command('example')
 def example():
     """
-    Run a test of the pipeline on an example image
+    Run a test of the pipeline on an example image with the Phase 1 models
     """
     scoutbot.example()
 
