@@ -44,7 +44,7 @@ def compute(img_filepath, grid1=True, grid2=True, ext=None, **kwargs):
     img = cv2.imread(img_filepath)
     shape = img.shape
 
-    log.info(f'Computing tiles (grid1={grid1}, grid2={grid2}) on {img_filepath}')
+    log.debug(f'Computing tiles (grid1={grid1}, grid2={grid2}) on {img_filepath}')
 
     grids = []
     if grid1:
@@ -56,7 +56,7 @@ def compute(img_filepath, grid1=True, grid2=True, ext=None, **kwargs):
     for grid, filepath in zip(grids, filepaths):
         assert tile_write(img, grid, filepath)
 
-    log.info(f'Rendered {len(filepaths)} tiles')
+    log.debug(f'Rendered {len(filepaths)} tiles')
 
     return shape, grids, filepaths
 
@@ -147,11 +147,12 @@ def tile_grid(
 
     Args:
         shape (tuple): the image's shape as ``(h, w, c)`` or ``(h, w)``
-        size (tuple): the tile's shape as ``(w, h)``
-        overlap (int): The amount of pixel overlap between each tile, for both the x-axis
-            and the y-axis.
-        offset (int): The amount of pixel offset for the entire grid
-        borders (bool): If :obj:`True`, include a set of border-only tiles.  Defaults to :obj:`True`.
+        size (tuple, optional): the tile's shape as ``(w, h)``
+        overlap (int, optional): The amount of pixel overlap between each tile, for
+            both the x-axis and the y-axis.
+        offset (int, optional): The amount of pixel offset for the entire grid
+        borders (bool, optional): If :obj:`True`, include a set of border-only tiles.
+            Defaults to :obj:`True`.
 
     Returns:
         list ( dict ): a list of grid coordinate dictionaries
